==> cas.cordova.base-0.2.0.tgz: package/src/ios/CASCBridge.h <==
//
//  CASCBridge.h
//  CleverAdsSolutions Construct
//
//  Copyright © 2020 Clever Ads Solutions. All rights reserved.
//

#import <Cordova/CDVViewController.h>
#import <Foundation/Foundation.h>
#import <Cordova/CDV.h>
#import <CleverAdsSolutions/CleverAdsSolutions-Swift.h>
#import "CASCCallback.h"

@interface CASCBridge : CDVPlugin<CASLoadDelegate>

@property (nonatomic, strong, nonnull) CASMediationManager *mediationManager;
@property (nonatomic, strong, nullable) CASBannerView *bannerView;
@property (nonatomic, strong, nonnull) CASSize *bannerActiveSize;

@property (nonatomic, strong, nullable) NSLayoutConstraint *horizontalConstraint;
@property (nonatomic, strong, nullable) NSLayoutConstraint *verticalConstraint;

@property (nonatomic, strong, nullable) CASCCallback *bannerCallback;
@property (nonatomic, strong, nullable) CASCCallback *interstitialCallback;
@property (nonatomic, strong, nullable) CASCCallback *rewardedCallback;
@property (nonatomic, strong, nullable) CASCCallback *appReturnCallback;

// ------ Clever Ads Solutions Main Methods

- (void)initialize:(CDVInvokedUrlCommand *)command;

- (void)initializeWithDefaultParameters:(CDVInvokedUrlCommand *)command;

- (void)validateIntegration:(CDVInvokedUrlCommand *)command;

- (void)setDebugMode:(CDVInvokedUrlCommand *)command;

- (void)skipNextReturnAds:(CDVInvokedUrlCommand *)command;

- (void)loadAd:(CDVInvokedUrlCommand *)command;

- (void)showAd:(CDVInvokedUrlCommand *)command;

- (void)hideBanner:(CDVInvokedUrlCommand *)command;

- (void)isAdReady:(CDVInvokedUrlCommand *)command;

- (void)getLastActiveMediation:(CDVInvokedUrlCommand *)command;

- (void)isEnabled:(CDVInvokedUrlCommand *)command;

- (void)enableAd:(CDVInvokedUrlCommand *)command;

- (void)setBannerSizeId:(CDVInvokedUrlCommand *)command;

- (void)setBannerPositionId:(CDVInvokedUrlCommand *)command;

- (void)setLastPageAdContent:(CDVInvokedUrlCommand *)command;

- (void)setBannerInSafeArea:(CDVInvokedUrlCommand *)command;

// ------ Clever Ads Solutions Settings

- (void)getSDKVersion:(CDVInvokedUrlCommand *)command;

- (void)setUserConsentStatus:(CDVInvokedUrlCommand *)command;

- (void)setDoNotSellStatus:(CDVInvokedUrlCommand *)command;

- (void)setTaggedAudience:(CDVInvokedUrlCommand *)command;

- (void)setMutedAdSounds:(CDVInvokedUrlCommand *)command;

- (void)setLoadingMode:(CDVInvokedUrlCommand *)command;

- (void)setRefreshBannerDelay:(CDVInvokedUrlCommand *)command;

- (void)setInterstitialInterval:(CDVInvokedUrlCommand *)command;

- (void)restartInterstitialInterval:(CDVInvokedUrlCommand *)command;

- (void)setAnalyticsCollectionEnabled:(CDVInvokedUrlCommand *)command;

- (void)setTestDeviceIds:(CDVInvokedUrlCommand *)command;

- (void)setAllowInterstitialAdsWhenRewardedCostAreLower:(CDVInvokedUrlCommand *)command;

- (void)setUserGender:(CDVInvokedUrlCommand *)command;

- (void)setUserAge:(CDVInvokedUrlCommand *)command;

- (void)getActiveMediationPattern:(CDVInvokedUrlCommand *)command;

- (void)isActiveMediationNetwork:(CDVInvokedUrlCommand *)command;

@end

==> cas.cordova.base-0.4.3.tgz: package/src/ios/CASCBridge.h <==
//
//  CASCBridge.h
//  CleverAdsSolutions Construct
//
//  Copyright © 2020 Clever Ads Solutions. All rights reserved.
//

#import <Cordova/CDVViewController.h>
#import <Foundation/Foundation.h>
#import <Cordova/CDV.h>
#import <CleverAdsSolutions/CleverAdsSolutions-Swift.h>
#import "CASCCallback.h"
#import "CASCBannerCallback.h"

@interface CASCBridge : CDVPlugin<CASLoadDelegate>

@property (nonatomic, strong, nonnull) CASMediationManager *mediationManager;
@property (nonatomic, strong, nullable) CASBannerView *bannerView;
@property (nonatomic, strong, nonnull) CASSize *bannerActiveSize;

@property (nonatomic, strong, nullable) NSLayoutConstraint *horizontalConstraint;
@property (nonatomic, strong, nullable) NSLayoutConstraint *verticalConstraint;

@property (nonatomic, strong, nullable) CASCBannerCallback *bannerCallback;
@property (nonatomic, strong, nullable) CASCCallback *interstitialCallback;
@property (nonatomic, strong, nullable) CASCCallback *rewardedCallback;
@property (nonatomic, strong, nullable) CASCCallback *appReturnCallback;

// ------ Clever Ads Solutions Main Methods

- (void)initialize:(CDVInvokedUrlCommand *)command;

- (void)initializeWithDefaultParameters:(CDVInvokedUrlCommand *)command;

- (void)validateIntegration:(CDVInvokedUrlCommand *)command;

- (void)setDebugMode:(CDVInvokedUrlCommand *)command;

- (void)skipNextReturnAds:(CDVInvokedUrlCommand *)command;

- (void)loadAd:(CDVInvokedUrlCommand *)command;

- (void)showAd:(CDVInvokedUrlCommand *)command;

- (void)hideBanner:(CDVInvokedUrlCommand *)command;

- (void)isAdReady:(CDVInvokedUrlCommand *)command;

- (void)getLastActiveMediation:(CDVInvokedUrlCommand *)command;

- (void)isEnabled:(CDVInvokedUrlCommand *)command;

- (void)enableAd:(CDVInvokedUrlCommand *)command;

- (void)setBannerSizeId:(CDVInvokedUrlCommand *)command;

- (void)setBannerPositionId:(CDVInvokedUrlCommand *)command;

- (void)setLastPageAdContent:(CDVInvokedUrlCommand *)command;

- (void)setBannerInSafeArea:(CDVInvokedUrlCommand *)command;

// ------ Clever Ads Solutions Settings

- (void)getSDKVersion:(CDVInvokedUrlCommand *)command;

- (void)setUserConsentStatus:(CDVInvokedUrlCommand *)command;

- (void)setDoNotSellStatus:(CDVInvokedUrlCommand *)command;

- (void)setTaggedAudience:(CDVInvokedUrlCommand *)command;

- (void)setMutedAdSounds:(CDVInvokedUrlCommand *)command;

- (void)setLoadingMode:(CDVInvokedUrlCommand *)command;

- (void)setRefreshBannerDelay:(CDVInvokedUrlCommand *)command;

- (void)setInterstitialInterval:(CDVInvokedUrlCommand *)command;

- (void)restartInterstitialInterval:(CDVInvokedUrlCommand *)command;

- (void)setAnalyticsCollectionEnabled:(CDVInvokedUrlCommand *)command;

- (void)setTestDeviceIds:(CDVInvokedUrlCommand *)command;

- (void)setAllowInterstitialAdsWhenRewardedCostAreLower:(CDVInvokedUrlCommand *)command;

- (void)setUserGender:(CDVInvokedUrlCommand *)command;

- (void)setUserAge:(CDVInvokedUrlCommand *)command;

- (void)getActiveMediationPattern:(CDVInvokedUrlCommand *)command;

- (void)isActiveMediationNetwork:(CDVInvokedUrlCommand *)command;

@end
